==> dnacentersdk-2.2.2.tar.gz: dnacentersdk-2.2.2/dnacentersdk/models/validators/v2_1_2/jsd_9e857b5a4a0bbcdb.py <==
# -*- coding: utf-8 -*-
"""DNA Center Reset Device data model.

Copyright (c) 2019-2020 Cisco and/or its affiliates.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


from __future__ import (
    absolute_import,
    division,
    print_function,
    unicode_literals,
)

import fastjsonschema
import json
from dnacentersdk.exceptions import MalformedRequest

from builtins import *


class JSONSchemaValidator9E857B5A4A0BBcdb(object):
    """Reset Device request schema definition."""
    def __init__(self):
        super(JSONSchemaValidator9E857B5A4A0BBcdb, self).__init__()
        self._validator = fastjsonschema.compile(json.loads(
            '''{
                "properties": {
                "deviceResetList": {
                "items": {
                "properties": {
                "configList": {
                "items": {
                "properties": {
                "configId": {
                "description":
                 "",
                "type": [
                "string",
                "null"
                ]
                },
                "configParameters": {
                "items": {
                "properties": {
                "key": {
                "description":
                 "",
                "type": [
                "string",
                "null"
                ]
                },
                "value": {
                "description":
                 "",
                "type": [
                "string",
                "null",
                "number"
                ]
                }
                },
                "type": [
                "object",
                "null"
                ]
                },
                "type": [
                "array",
                "null"
                ]
                }
                },
                "type": [
                "object",
                "null"
                ]
                },
                "type": [
                "array",
                "null"
                ]
                },
                "deviceId": {
                "description":
                 "",
                "type": [
                "string",
                "null"
                ]
                },
                "licenseLevel": {
                "description":
                 "",
                "type": [
                "string",
                "null"
                ]
                },
                "licenseType": {
                "description":
                 "",
                "type": [
                "string",
                "null"
                ]
                },
                "topOfStackSerialNumber": {
                "description":
                 "",
                "type": [
                "string",
                "null"
                ]
                }
                },
                "type": [
                "object",
                "null"
                ]
                },
                "type": [
                "array",
                "null"
                ]
                },
                "projectId": {
                "description":
                 "",
                "type": [
                "string",
                "null"
                ]
                },
                "workflowId": {
                "description":
                 "",
                "type": [
                "string",
                "null"
                ]
                }
                },
                "type": "object"
                }'''.replace("\n" + ' ' * 16, '')
        ))

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                '{} is invalid. Reason: {}'.format(request, e.message)
            )

==> dnacentersdk-2.4.0.tar.gz: dnacentersdk-2.4.0/dnacentersdk/models/validators/v1_3_3/jsd_9e857b5a4a0bbcdb.py <==
# -*- coding: utf-8 -*-
"""Cisco DNA Center Reset Device data model.

Copyright (c) 2019-2021 Cisco Systems.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


from __future__ import (
    absolute_import,
    division,
    print_function,
    unicode_literals,
)

import fastjsonschema
import json
from dnacentersdk.exceptions import MalformedRequest

from builtins import *


class JSONSchemaValidator9E857B5A4A0BBcdb(object):
    """Reset Device request schema definition."""
    def __init__(self):
        super(JSONSchemaValidator9E857B5A4A0BBcdb, self).__init__()
        self._validator = fastjsonschema.compile(json.loads(
            '''{
                "properties": {
                "deviceResetList": {
                "items": {
                "properties": {
                "configList": {
                "items": {
                "properties": {
                "configId": {
                "type": [
                "string",
                "null"
                ]
                },
                "configParameters": {
                "items": {
                "properties": {
                "key": {
                "type": [
                "string",
                "null"
                ]
                },
                "value": {
                "type": [
                "string",
                "null",
                "number"
                ]
                }
                },
                "type": [
                "object",
                "null"
                ]
                },
                "type": [
                "array",
                "null"
                ]
                }
                },
                "type": [
                "object",
                "null"
                ]
                },
                "type": [
                "array",
                "null"
                ]
                },
                "deviceId": {
                "type": [
                "string",
                "null"
                ]
                },
                "licenseLevel": {
                "type": [
                "string",
                "null"
                ]
                },
                "licenseType": {
                "type": [
                "string",
                "null"
                ]
                },
                "topOfStackSerialNumber": {
                "type": [
                "string",
                "null"
                ]
                }
                },
                "type": [
                "object",
                "null"
                ]
                },
                "type": [
                "array",
                "null"
                ]
                },
                "projectId": {
                "type": [
                "string",
                "null"
                ]
                },
                "workflowId": {
                "type": [
                "string",
                "null"
                ]
                }
                },
                "type": "object"
                }'''.replace("\n" + ' ' * 16, '')
        ))

    def validate(self, request):
        try:
            self._validator(request)
        except fastjsonschema.exceptions.JsonSchemaException as e:
            raise MalformedRequest(
                '{} is invalid. Reason: {}'.format(request, e.message)
            )
